indian_number_utils
library
Functions
-
formatIndianCompact(num value, {int decimals = 2})
→ String
-
Format a number into a compact Indian-style string.
-
formatIndianNumber(num value)
→ String
-
Format an integer using the Indian numbering system grouping:
1234 -> 1,234
1234567 -> 12,34,567
123456789 -> 12,34,56,789
-
indianNumberToWords(num value)
→ String
-
Convert an integer number into Indian-style words.
Examples:
0 -> "zero"
15 -> "fifteen"
1234 -> "one thousand two hundred thirty four"
150000 -> "one lakh fifty thousand"
12345678 -> "one crore twenty three lakh forty five thousand six hundred seventy eight"